about summary refs log tree commit diff
path: root/tvix/store/build.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tvix/store/build.rs')
-rw-r--r--tvix/store/build.rs46
1 files changed, 27 insertions, 19 deletions
diff --git a/tvix/store/build.rs b/tvix/store/build.rs
index 3fdc7418c1..ef1674cfbd 100644
--- a/tvix/store/build.rs
+++ b/tvix/store/build.rs
@@ -1,24 +1,32 @@
 use std::io::Result;
 
 fn main() -> Result<()> {
-    tonic_build::configure()
-        .build_server(true)
-        .build_client(true)
-        .compile(
-            &[
-                "tvix/store/protos/castore.proto",
-                "tvix/store/protos/pathinfo.proto",
-                "tvix/store/protos/rpc_blobstore.proto",
-                "tvix/store/protos/rpc_directory.proto",
-                "tvix/store/protos/rpc_pathinfo.proto",
-            ],
-            // If we are in running `cargo build` manually, using `../..` works fine,
-            // but in case we run inside a nix build, we need to instead point PROTO_ROOT
-            // to a sparseTree containing that structure.
-            &[match std::env::var_os("PROTO_ROOT") {
-                Some(proto_root) => proto_root.to_str().unwrap().to_owned(),
-                None => "../..".to_string(),
-            }],
-        )?;
+    #[allow(unused_mut)]
+    let mut builder = tonic_build::configure();
+
+    #[cfg(feature = "reflection")]
+    {
+        let out_dir = std::path::PathBuf::from(std::env::var("OUT_DIR").unwrap());
+        let descriptor_path = out_dir.join("tvix.store.v1.bin");
+
+        builder = builder.file_descriptor_set_path(&descriptor_path);
+    };
+
+    builder.build_server(true).build_client(true).compile(
+        &[
+            "tvix/store/protos/castore.proto",
+            "tvix/store/protos/pathinfo.proto",
+            "tvix/store/protos/rpc_blobstore.proto",
+            "tvix/store/protos/rpc_directory.proto",
+            "tvix/store/protos/rpc_pathinfo.proto",
+        ],
+        // If we are in running `cargo build` manually, using `../..` works fine,
+        // but in case we run inside a nix build, we need to instead point PROTO_ROOT
+        // to a sparseTree containing that structure.
+        &[match std::env::var_os("PROTO_ROOT") {
+            Some(proto_root) => proto_root.to_str().unwrap().to_owned(),
+            None => "../..".to_string(),
+        }],
+    )?;
     Ok(())
 }